from setuptools import setup, find_packages

setup(
    name="tox-direct",
    description="plugin for tox - run everything directly (tox creates no virtual env)",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Oliver Bestwalter",
    author_email="oliver@bestwalter.de",
    url="https://github.com/obestwalter/tox-direct",
    license="MIT",
    version="0.1.3",
    package_dir={"": "src"},
    packages=find_packages("src"),
    entry_points={"tox": ["direct = tox_direct.hookimpls"]},
    install_requires=["tox>=3.0"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Framework :: tox",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Software Development :: Testing",
    ],
)
